audtorch.metrics
================

.. automodule:: audtorch.metrics

EnergyConservingLoss
--------------------

.. autoclass:: EnergyConservingLoss
    :members:

PearsonR
--------

.. autoclass:: PearsonR
    :members:

ConcordanceCC
-------------

.. autoclass:: ConcordanceCC
    :members:
